pos_multiply — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pos_multiply

poscar_modify.pos_multiply(factor: np.ndarray | list[float], cartesian: bool = True)

  Multiplies each (x,y,z) position by the Factor (Fx,Fy,Fz)

  Parameters:

    - factor (np.ndarray|list[float]) – array or list with 3 numbers, the x,y,z factors to scale each position

    - cartesian (bool) – should the operation be done in Cartesian (False) or direct (True) coordinates? Default is True